SliteClient

Struct SliteClient 

pub struct SliteClient { /* private fields */ }
Typed Slite integration client for Leash.

Implementations

Source

impl SliteClient

pub fn new(leash: LeashIntegrations) -> Self

Create a new SliteClient.

pub async fn search_notes( &self, params: &SearchNotesParams, ) -> Result<Value, LeashError>

Searches notes in Slite based on a query and returns the top search results.

pub async fn ask_slite( &self, params: &AskSliteParams, ) -> Result<Value, LeashError>

Asks a question to Slite and returns an answer with sources.

pub async fn get_note( &self, params: &GetNoteParams, ) -> Result<Value, LeashError>

Retrieves a specific note from Slite by its ID.

pub async fn get_note_children( &self, params: &GetNoteChildrenParams, ) -> Result<Value, LeashError>

Retrieves all child notes of a specific note from Slite.

pub async fn create_note( &self, params: &CreateNoteParams, ) -> Result<Value, LeashError>

Creates a new note in Slite with the specified title and optional content.

pub async fn update_note( &self, params: &UpdateNoteParams, ) -> Result<Value, LeashError>

Updates an existing note in Slite. Can update the title and/or content.